<?xml version="1.0" encoding="utf-8"?>
<!-- copyright@ 2020, Waregram , All right Reserved. -->
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:include href="../../../../xsl_util.xsl"/>

<xsl:output method="text" encoding="utf-8" indent="yes"/>

<xsl:param name = "export_proxy_class_id" />

<xsl:template match="/">
  <xsl:for-each select="/nerv_icde/component/proxy_list/row[id=$export_proxy_class_id]">
    <xsl:variable name="method_domain_id" select="method_domain_id" />
    <xsl:variable name="interface_name" select="interface_name" />
    <xsl:variable name="class_name" select="class_name" />

#include "<xsl:value-of select="$class_name"/>.h"

<xsl:value-of select="$class_name"/>::<xsl:value-of select="$class_name"/>()
{
}

<xsl:value-of select="$class_name"/>::~<xsl:value-of select="$class_name"/>()
{
}

void <xsl:value-of select="$class_name"/>::on_object_create()
{
    PyGILState_STATE state = PyGILState_Ensure();
    this->get_override("on_object_create")();
    PyGILState_Release(state);
}

void <xsl:value-of select="$class_name"/>::on_object_destroy()
{
    PyGILState_STATE state = PyGILState_Ensure();
    this->get_override("on_object_destroy")();
    PyGILState_Release(state);
}

    <xsl:for-each select="/nerv_icde/methoddomain/row[id=$method_domain_id]">
      <xsl:for-each select="interface/row[name=$interface_name]">
        <xsl:for-each select="membermethod/row">
          <xsl:variable name="method_name" select="method_name" />
          <xsl:for-each select="../../../../method/row[name=$method_name]">

            <xsl:variable name="in_data_domain_namespace">
              <xsl:call-template name="get_data_domain_namespace">
                <xsl:with-param name="data_domain_id" select="in_data_domain_id" />
              </xsl:call-template>
            </xsl:variable>
            <xsl:variable name="out_data_domain_namespace">
              <xsl:call-template name="get_data_domain_namespace">
                <xsl:with-param name="data_domain_id" select="out_data_domain_id" />
              </xsl:call-template>
            </xsl:variable>
            <xsl:choose>
              <xsl:when test="type='CALL'">
              </xsl:when>
              <xsl:when test="type='SIGNAL'">
              </xsl:when>

              <xsl:when test="type='EVENT'">
void <xsl:value-of select="$class_name"/>::on_<xsl:value-of select="$method_name"/>_disconnected()
{
    PyGILState_STATE state = PyGILState_Ensure();
    this->get_override("on_<xsl:value-of select="$method_name"/>_disconnected")();
    PyGILState_Release(state);
}
                <xsl:choose >
                  <xsl:when test="out_data='(null)'">
void <xsl:value-of select="$class_name"/>::on_<xsl:value-of select="$method_name"/>(const double&amp; in_elapsed_time)
{
    PyGILState_STATE state = PyGILState_Ensure();
    this->get_override("on_<xsl:value-of select="$method_name"/>")(in_elapsed_time);
    PyGILState_Release(state);
}
                  </xsl:when>
                  <xsl:otherwise>
void <xsl:value-of select="$class_name"/>::on_<xsl:value-of select="$method_name"/>(<xsl:value-of select="$out_data_domain_namespace"/>::<xsl:value-of select="out_data"/>* pOut, const double&amp; in_elapsed_time)
{
    PyGILState_STATE state = PyGILState_Ensure();
    this->get_override("on_<xsl:value-of select="$method_name"/>")(pOut, in_elapsed_time);
    PyGILState_Release(state);
}
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:when>


              <xsl:when test="type='COMMAND'">
void <xsl:value-of select="$class_name"/>::on_<xsl:value-of select="$method_name"/>_disconnected()
{
    PyGILState_STATE state = PyGILState_Ensure();
    this->get_override("on_<xsl:value-of select="$method_name"/>_disconnected")();
    PyGILState_Release(state);
}
              </xsl:when>


              <xsl:when test="type='INFORMATION'">
void <xsl:value-of select="$class_name"/>::on_<xsl:value-of select="$method_name"/>_disconnected()
{
    PyGILState_STATE state = PyGILState_Ensure();
    this->get_override("on_<xsl:value-of select="$method_name"/>_disconnected")();
    PyGILState_Release(state);
}
                <xsl:choose >
                  <xsl:when test="out_data='(null)'">
void <xsl:value-of select="$class_name"/>::on_<xsl:value-of select="$method_name"/>_sync( const Nerv::sender_sync_model_t&amp; in_sync_model, const double&amp; in_elapsed, const double&amp; in_limit )
{
    PyGILState_STATE state = PyGILState_Ensure();
    this->get_override("on_<xsl:value-of select="$method_name"/>_sync")(in_sync_model, in_elapsed, in_limit);
    PyGILState_Release(state);
}
                  </xsl:when>
                  <xsl:otherwise>
void <xsl:value-of select="$class_name"/>::on_<xsl:value-of select="$method_name"/>_sync( const Nerv::sender_sync_model_t&amp; in_sync_model, const double&amp; in_elapsed, const double&amp; in_limit, <xsl:value-of select="$out_data_domain_namespace"/>::<xsl:value-of select="out_data"/> const* const pin_buffer )
{
    PyGILState_STATE state = PyGILState_Ensure();
    this->get_override("on_<xsl:value-of select="$method_name"/>_sync")(in_sync_model, in_elapsed, in_limit, pin_buffer);
    PyGILState_Release(state);
}
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:when>


              <xsl:when test="type='BROADCAST'">
                <xsl:choose >
                  <xsl:when test="out_data='(null)'">
void <xsl:value-of select="$class_name"/>::on_<xsl:value-of select="$param_method_name"/>_broadcast(const ::Nerv::server_addr_t&amp; in_server, const double&amp; in_elapsed_time)
{
    PyGILState_STATE state = PyGILState_Ensure();
    this->get_override("on_<xsl:value-of select="$param_method_name"/>_broadcast")(in_server, in_elapsed_time);
    PyGILState_Release(state);
}
                  </xsl:when>
                  <xsl:otherwise>
void <xsl:value-of select="$class_name"/>::on_<xsl:value-of select="$param_method_name"/>_broadcast(const ::Nerv::server_addr_t&amp; in_server, <xsl:value-of select="$out_data_domain_namespace"/>::<xsl:value-of select="out_data"/> * const pin_buf, const double&amp; in_elapsed_time)
{
    PyGILState_STATE state = PyGILState_Ensure();
    this->get_override("on_<xsl:value-of select="$param_method_name"/>_broadcast")(in_server, pin_buf, in_elapsed_time);
    PyGILState_Release(state);
}
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:when>
            </xsl:choose>
          </xsl:for-each>
        </xsl:for-each>
      </xsl:for-each>
    </xsl:for-each>
  </xsl:for-each>
</xsl:template>

</xsl:stylesheet>
