<?xml version="1.0" encoding="utf-8"?>
<!-- copyright@ 2020, Waregram , All right Reserved. -->
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:include href="../../../../xsl_util.xsl"/>

<xsl:output method="text" encoding="utf-8" indent="yes"/>

<xsl:param name = "export_proxy_class_id" />

<xsl:template match="/">
  <xsl:for-each select="/nerv_icde/component/proxy_list/row[id=$export_proxy_class_id]">
    <xsl:variable name="method_domain_id" select="method_domain_id" />
    <xsl:variable name="interface_name" select="interface_name" />
    <xsl:variable name="class_name" select="class_name" />

    <xsl:variable name="method_domain_path">
      <xsl:call-template name="get_method_domain_path">
        <xsl:with-param name="mathod_domain_id" select="$method_domain_id" />
      </xsl:call-template>
    </xsl:variable>

    <xsl:variable name="method_domain_namespace">
      <xsl:call-template name="replace">
        <xsl:with-param name="text" select="$method_domain_path" />
        <xsl:with-param name="replace" select="'/'" />
        <xsl:with-param name="by" select="'::'" />
      </xsl:call-template>
    </xsl:variable>

#pragma once

#include &lt;Nerv/Method<xsl:value-of select="$method_domain_path"/>/<xsl:value-of select="method_domain_name"/>.h&gt;

#include &lt;boost/python.hpp&gt;
namespace py = boost::python;



class <xsl:value-of select="$class_name"/> : public Nerv::Method<xsl:value-of select="$method_domain_namespace"/>::proxy_interface_<xsl:value-of select="$interface_name"/>, public py::wrapper&lt;<xsl:value-of select="$class_name"/>&gt;
{
public:
    <xsl:value-of select="$class_name"/>();
    ~<xsl:value-of select="$class_name"/>();

    virtual void on_object_create();
    virtual void on_object_destroy();

    <xsl:for-each select="/nerv_icde/methoddomain/row[id=$method_domain_id]">
      <xsl:for-each select="interface/row[name=$interface_name]">
        <xsl:for-each select="membermethod/row">
          <xsl:variable name="method_name" select="method_name" />
          <xsl:for-each select="../../../../method/row[name=$method_name]">

            <xsl:variable name="in_data_domain_namespace">
              <xsl:call-template name="get_data_domain_namespace">
                <xsl:with-param name="data_domain_id" select="in_data_domain_id" />
              </xsl:call-template>
            </xsl:variable>
            <xsl:variable name="out_data_domain_namespace">
              <xsl:call-template name="get_data_domain_namespace">
                <xsl:with-param name="data_domain_id" select="out_data_domain_id" />
              </xsl:call-template>
            </xsl:variable>

            <xsl:if test="type!='CALL' and type!='SIGNAL'" >
    /********************************************************************************************************************************************
        Method       : <xsl:value-of select="name"/>
        Input        : <xsl:if test="in_data != ''"><xsl:value-of select="$in_data_domain_namespace"/>::<xsl:value-of select="in_data"/></xsl:if>
        output       : <xsl:if test="out_data != ''"><xsl:value-of select="$out_data_domain_namespace"/>::<xsl:value-of select="out_data"/></xsl:if>
        Method Type  : <xsl:value-of select="type"/>
        Code         : <xsl:value-of select="code"/>
        Description  : <xsl:value-of select="description"/>
    ********************************************************************************************************************************************/
            </xsl:if>

            <xsl:choose>
              <xsl:when test="type='EVENT'">
    void on_<xsl:value-of select="$method_name"/>_disconnected();
                <xsl:choose >
                  <xsl:when test="out_data='(null)'">
    void on_<xsl:value-of select="$method_name"/>(const double&amp; in_elapsed_time);
                  </xsl:when>
                  <xsl:otherwise>
    void on_<xsl:value-of select="$method_name"/>(<xsl:value-of select="$out_data_domain_namespace"/>::<xsl:value-of select="out_data"/>* pOut, const double&amp; in_elapsed_time);
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:when>


              <xsl:when test="type='COMMAND'">
    void on_<xsl:value-of select="$method_name"/>_disconnected();
              </xsl:when>


              <xsl:when test="type='INFORMATION'">
    void on_<xsl:value-of select="$method_name"/>_disconnected();
                <xsl:choose >
                  <xsl:when test="out_data='(null)'">
    void on_<xsl:value-of select="$method_name"/>_sync( const Nerv::sender_sync_model_t&amp; in_sync_model, const double&amp; in_elapsed, const double&amp; in_limit );
                  </xsl:when>
                  <xsl:otherwise>
    void on_<xsl:value-of select="$method_name"/>_sync( const Nerv::sender_sync_model_t&amp; in_sync_model, const double&amp; in_elapsed, const double&amp; in_limit, <xsl:value-of select="$out_data_domain_namespace"/>::<xsl:value-of select="out_data"/> const* const pin_buffer );
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:when>


              <xsl:when test="type='BROADCAST'">
                <xsl:choose >
                  <xsl:when test="out_data='(null)'">
    void on_<xsl:value-of select="$param_method_name"/>_broadcast(const ::Nerv::server_addr_t&amp; in_server, const double&amp; in_elapsed_time);
                  </xsl:when>
                  <xsl:otherwise>
    void on_<xsl:value-of select="$param_method_name"/>_broadcast(const ::Nerv::server_addr_t&amp; in_server, <xsl:value-of select="$out_data_domain_namespace"/>::<xsl:value-of select="out_data"/> * const pin_buf, const double&amp; in_elapsed_time);
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:when>
            </xsl:choose>
          </xsl:for-each>
        </xsl:for-each>
      </xsl:for-each>
    </xsl:for-each>
};


  </xsl:for-each>
</xsl:template>

</xsl:stylesheet>
